@@ -4,7 +4,7 @@ set -e
 
 sudo apt update
 
-sudo DEBIAN_FRONTEND=noninteractive apt-get install -y cmake g++ pkg-config \
+sudo DEBIAN_FRONTEND=noninteractive apt-get install -y cmake g++ pkg-config wget \
   libfftw3-dev zlib1g-dev libasound2-dev libwavpack-dev libudev-dev \
   libwxgtk3.0-gtk3-dev docbook-xsl xsltproc gettext po4a imagemagick patchelf libgtk-3-dev librsvg2-dev
 
