@@ -65,6 +65,8 @@ GO_WIN_PRMS="-DCMAKE_SYSTEM_NAME=Windows \
   -DCMAKE_SYSTEM_PROCESSOR=x86_64 \
   -DCMAKE_VERBOSE_MAKEFILE=ON \
   -DRTAUDIO_USE_ASIO=ON -DASIO_SDK_DIR=/usr/local/asio-sdk \
+  -DVC_PATH=/usr/local/share/wine/msvc/VC/Tools/MSVC/14.29.30133/bin/Hostx86/x86 \
+  -DCV2PDB_EXE=/usr/local/share/wine/cv2pdb/cv2pdb.exe \
   -DIMPORT_EXECUTABLES=../build-tools/ImportExecutables.cmake"
 GO_PRMS="-DGO_USE_JACK=ON $CMAKE_VERSION_PRMS"
 
