@@ -24,6 +24,7 @@ private:
   wxString m_OrganBuilder;
   wxString m_RecordingDetail;
   wxString m_ArchiveID;
+  wxString m_ArchivePath;
   bool m_NamesInitialized;
   long m_LastUse;
   GOMidiReceiverBase m_midi;
@@ -32,6 +33,7 @@ public:
   GOOrgan(
     wxString odf,
     wxString archive,
+    wxString archivePath,
     wxString church_name,
     wxString organ_builder,
     wxString recording_detail);
@@ -44,10 +46,15 @@ public:
   void Save(GOConfigWriter &cfg, wxString group, GOMidiMap &map);
 
   const wxString &GetODFPath() const;
+  void SetODFPath(const wxString &newPath) { m_ODF = newPath; }
   const wxString &GetChurchName() const;
   const wxString &GetOrganBuilder() const;
   const wxString &GetRecordingDetail() const;
   const wxString &GetArchiveID() const;
+  const wxString &GetArchivePath() const { return m_ArchivePath; }
+  void SetArchivePath(const wxString &archivePath) {
+    m_ArchivePath = archivePath;
+  }
   const wxString GetOrganHash() const;
   long GetLastUse() const;
   const wxString GetUITitle() const;
