@@ -8,7 +8,9 @@
 #ifndef GOMIDIFILEREADER_H
 #define GOMIDIFILEREADER_H
 
+#include <map>
 #include <stdint.h>
+
 #include <wx/string.h>
 
 #include "GOBuffer.h"
@@ -21,14 +23,17 @@ private:
   GOMidiMap &m_Map;
   GOBuffer<uint8_t> m_Data;
   unsigned m_Tracks;
-  float m_Speed;
+  float m_Speed; // the global speed from the file header
   unsigned m_Pos;
   unsigned m_TrackEnd;
+  bool m_IsFirstTrackComplete; // the first track has been read completely
   unsigned m_LastStatus;
-  unsigned m_CurrentSpeed;
+  float m_CurrentSpeed; // the current speed for the current track
+  float m_CurrentSpeedTo;
   float m_LastTime;
+  std::map<float, float>
+    m_TempoMap; // maps start time to the speed from the first track
   unsigned m_PPQ;
-  unsigned m_Tempo;
 
   bool StartTrack();
   unsigned DecodeTime();
