@@ -47,14 +47,9 @@ public:
   GOTemperamentCent(
     wxString name, wxString title, wxString group, wxString groupTitle);
 
-  virtual float GetOffset(
-    bool ignorepitch,
-    unsigned midi_number,
-    unsigned wav_midi_number,
-    float wav_pitch_fract,
-    float harmonic_number,
-    float pitch_correction,
-    float default_tuning) const;
+  virtual float GetOffset(unsigned index) const override {
+    return m_Tuning[index];
+  }
 };
 
 #endif
