@@ -8,14 +8,7 @@
 #ifndef GOCONDITION_H
 #define GOCONDITION_H
 
-#if defined GO_STD_MUTEX
 #include <condition_variable>
-#elif defined WX_MUTEX
-#include <wx/thread.h>
-#else
-#include "GOWaitQueue.h"
-#include "atomic.h"
-#endif
 
 #include "GOMutex.h"
 #include "GOThread.h"
@@ -25,16 +18,8 @@ public:
   enum { SIGNAL_RECEIVED = 0x1, MUTEX_LOCKED = 0x2 };
 
 private:
-#if defined GO_STD_MUTEX
   std::timed_mutex &r_mutex;
   std::condition_variable_any m_condition;
-#elif defined WX_MUTEX
-  wxCondition m_condition;
-#else
-  atomic_int m_Waiters;
-  GOWaitQueue m_Wait;
-  GOMutex &m_Mutex;
-#endif
 
   GOCondition(const GOCondition &) = delete;
   const GOCondition &operator=(const GOCondition &) = delete;
