@@ -8,27 +8,13 @@
 #ifndef GOMUTEX_H
 #define GOMUTEX_H
 
-#ifdef GO_STD_MUTEX
 #include <mutex>
-#elif WX_MUTEX
-#include <wx/thread.h>
-#else
-#include "GOWaitQueue.h"
-#include "atomic.h"
-#endif
 
 #include "GOThread.h"
 
 class GOMutex {
 private:
-#if defined GO_STD_MUTEX
   std::timed_mutex m_mutex;
-#elif defined WX_MUTEX
-  wxMutex m_Mutex;
-#else
-  GOWaitQueue m_Wait;
-  atomic_int m_Lock;
-#endif
 
   const char *volatile m_LockerInfo;
 
@@ -43,9 +29,7 @@ public:
   GOMutex();
   ~GOMutex();
 
-#if defined GO_STD_MUTEX
   std::timed_mutex &GetTimedMutex() { return m_mutex; };
-#endif
 
   bool LockOrStop(const char *lockerInfo = NULL, GOThread *pThread = NULL);
   void Lock(const char *lockerInfo = NULL) { LockOrStop(lockerInfo, NULL); }
