@@ -50,7 +50,7 @@ const wxCmdLineEntryDesc GOApp::m_cmdLineDesc[] = {
   {wxCMD_LINE_OPTION,
    wxTRANSLATE("i"),
    wxTRANSLATE("instance"),
-   wxTRANSLATE("specifiy GrandOrgue instance name"),
+   wxTRANSLATE("specify GrandOrgue instance name"),
    wxCMD_LINE_VAL_STRING,
    wxCMD_LINE_PARAM_OPTIONAL},
   {wxCMD_LINE_PARAM,
@@ -154,9 +154,6 @@ int GOApp::OnRun() { return wxApp::OnRun(); }
 
 int GOApp::OnExit() {
   wxLog::SetActiveTarget(NULL);
-  delete m_soundSystem;
-  delete m_config;
-  delete m_Log;
 
   int rc = wxApp::OnExit();
 
@@ -168,4 +165,24 @@ int GOApp::OnExit() {
   return rc;
 }
 
+void GOApp::CleanUp() {
+  // Ensure that GOFrame and other objects are destroyed before deleting
+  wxApp::CleanUp();
+
+  // CleanUp() may be called even if OnInit() has not succeed, so we need to
+  // check
+  if (m_soundSystem) {
+    delete m_soundSystem;
+    m_soundSystem = nullptr;
+  }
+  if (m_config) {
+    delete m_config;
+    m_config = nullptr;
+  }
+  if (m_Log) {
+    delete m_Log;
+    m_Log = nullptr;
+  }
+}
+
 void GOApp::SetRestart() { m_Restart = true; }
\ No newline at end of file
