@@ -10,10 +10,10 @@
 
 #include <wx/string.h>
 
-#include "GOButton.h"
-#include "GOCombinationElement.h"
+#include "combinations/model/GOCombinationElement.h"
+#include "control/GOButtonControl.h"
 
-class GODrawstop : public GOButton, public GOCombinationElement {
+class GODrawstop : public GOButtonControl, public GOCombinationElement {
 public:
   typedef enum {
     FUNCTION_INPUT,
@@ -47,7 +47,7 @@ protected:
   void PreparePlayback();
 
 public:
-  GODrawstop(GODefinitionFile *organfile);
+  GODrawstop(GOOrganController *organController);
   void Init(GOConfigReader &cfg, wxString group, wxString name);
   void Load(GOConfigReader &cfg, wxString group);
   void RegisterControlled(GODrawstop *sw);
