@@ -22,7 +22,6 @@
 #include "loader/GOFileStore.h"
 #include "model/GOModificationListener.h"
 #include "model/GOOrganModel.h"
-#include "model/pipe-config/GOPipeConfigTreeNode.h"
 
 #include "GOBitmapCache.h"
 #include "GOMainWindowData.h"
@@ -54,7 +53,6 @@ class GOSoundSampler;
 typedef struct _GOHashType GOHashType;
 
 class GOOrganController : public GOEventDistributor,
-                          private GOPipeUpdateCallback,
                           public GOTimer,
                           public GOOrganModel,
                           public GOModificationListener {
@@ -77,11 +75,11 @@ private:
   GOMidiPlayer *m_MidiPlayer;
   GOMidiRecorder *m_MidiRecorder;
   int m_volume;
-  bool m_IgnorePitch;
   wxString m_Temperament;
   unsigned m_releaseTail = 0;
 
   bool m_b_customized;
+  float m_CurrentPitch; // organ pitch
   bool m_OrganModified; // always m_IsOrganModified >= IsModelModified()
   bool m_DivisionalsStoreIntermanualCouplers;
   bool m_DivisionalsStoreIntramanualCouplers;
@@ -110,7 +108,6 @@ private:
 
   GOMemoryPool m_pool;
   GOBitmapCache m_bitmaps;
-  GOPipeConfigTreeNode m_PipeConfig;
   GOConfig &m_config;
   GOCombinationDefinition m_GeneralTemplate;
   GOLabelControl m_PitchLabel;
@@ -130,10 +127,6 @@ private:
   void SetTemperament(const GOTemperament &temperament);
   void PreconfigRecorder();
 
-  void UpdateAmplitude();
-  void UpdateTuning();
-  void UpdateAudioGroup();
-
   wxString GetOrganHash();
 
 public:
@@ -188,7 +181,6 @@ public:
   GOMemoryPool &GetMemoryPool();
   GOConfig &GetSettings();
   GOBitmapCache &GetBitmapCache();
-  GOPipeConfigNode &GetPipeConfig();
   void SetTemperament(wxString name);
   wxString GetTemperament();
   void MarkSectionInUse(wxString name);
@@ -211,9 +203,6 @@ public:
   void SetVolume(int volume);
   int GetVolume();
 
-  void SetIgnorePitch(bool ignorepitch);
-  bool GetIgnorePitch();
-
   unsigned GetReleaseTail() const { return m_releaseTail; }
   void SetReleaseTail(unsigned releaseTail);
 
