@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -11,7 +11,7 @@
 #include <wx/scrolwin.h>
 #include <wx/toplevel.h>
 
-#include "GOView.h"
+#include "document-base/GOView.h"
 
 class GOGUIControl;
 class GOGUIPanel;
