@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -10,9 +10,13 @@
 GOMidiDeviceConfig::GOMidiDeviceConfig(
   const wxString &logicalName,
   const wxString &regEx,
+  const wxString portName,
+  const wxString apiName,
   bool isEnabled,
   const wxString &physicalName)
   : m_LogicalName(logicalName),
+    m_PortName(portName),
+    m_ApiName(apiName),
     m_IsEnabled(isEnabled),
     m_PhysicalName(physicalName) {
   SetRegEx(regEx);
@@ -29,6 +33,8 @@ void GOMidiDeviceConfig::SetRegEx(const wxString &regEx) {
 
 void GOMidiDeviceConfig::Assign(const GOMidiDeviceConfig &src) {
   m_LogicalName = src.m_LogicalName;
+  m_PortName = src.m_PortName;
+  m_ApiName = src.m_ApiName;
   SetRegEx(src.m_RegEx);
   m_IsEnabled = src.m_IsEnabled;
   m_ChannelShift = src.m_ChannelShift;
