@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -22,6 +22,8 @@ public:
 
   wxString m_LogicalName;
   wxString m_RegEx;
+  wxString m_PortName;
+  wxString m_ApiName;
   bool m_IsEnabled;
 
   // Midi-in only
@@ -34,6 +36,8 @@ public:
   GOMidiDeviceConfig(
     const wxString &logicalName,
     const wxString &regEx = wxEmptyString,
+    const wxString portName = wxEmptyString,
+    const wxString apiName = wxEmptyString,
     bool isEnabled = true,
     const wxString &physicalName = wxEmptyString);
 
