@@ -11,16 +11,16 @@
 #include "gui/GOGUIPanelCreator.h"
 
 class GOGUIPanel;
-class GODefinitionFile;
+class GOOrganController;
 
 class GOGUIFloatingPanel : public GOGUIPanelCreator {
 private:
-  GODefinitionFile *m_organfile;
+  GOOrganController *m_OrganController;
 
   GOGUIPanel *CreateFloatingPanel(GOConfigReader &cfg);
 
 public:
-  GOGUIFloatingPanel(GODefinitionFile *organfile);
+  GOGUIFloatingPanel(GOOrganController *organController);
   ~GOGUIFloatingPanel();
 
   void CreatePanels(GOConfigReader &cfg);
