@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -9,6 +9,8 @@
 
 #include "config/GOConfigReader.h"
 
+#include "go_gui_utils.h"
+
 GOGUIHW1DisplayMetrics::GOGUIHW1DisplayMetrics(
   GOConfigReader &ini, wxString group)
   : GOGUIDisplayMetrics() {
@@ -33,8 +35,8 @@ GOGUIHW1DisplayMetrics::GOGUIHW1DisplayMetrics(
     = ini.ReadStringTrim(ODFSetting, group, wxT("DispControlLabelFont"));
   m_DispShortcutKeyLabelFont
     = ini.ReadStringTrim(ODFSetting, group, wxT("DispShortcutKeyLabelFont"));
-  m_DispShortcutKeyLabelColour
-    = ini.ReadColor(ODFSetting, group, wxT("DispShortcutKeyLabelColour"));
+  m_DispShortcutKeyLabelColour = logicalToWxColour(
+    ini.ReadColor(ODFSetting, group, wxT("DispShortcutKeyLabelColour")));
   m_DispGroupLabelFont
     = ini.ReadStringTrim(ODFSetting, group, wxT("DispGroupLabelFont"));
   m_DispDrawstopCols
