@@ -11,16 +11,16 @@
 #include "gui/GOGUIPanelCreator.h"
 
 class GOGUIPanel;
-class GODefinitionFile;
+class GOOrganController;
 
 class GOGUIMasterPanel : public GOGUIPanelCreator {
 private:
-  GODefinitionFile *m_organfile;
+  GOOrganController *m_OrganController;
 
   GOGUIPanel *CreateMasterPanel(GOConfigReader &cfg);
 
 public:
-  GOGUIMasterPanel(GODefinitionFile *organfile);
+  GOGUIMasterPanel(GOOrganController *organController);
   virtual ~GOGUIMasterPanel();
 
   void CreatePanels(GOConfigReader &cfg);
