@@ -27,14 +27,32 @@ private:
   double m_Scale;
   double m_FontScale;
 
+  /**
+   * A point where the mouse has been pressed. Used for deduplication
+   */
+  wxPoint m_PressedPoint;
+
   void initFont();
   void OnCreate(wxWindowCreateEvent &event);
   void OnDraw(wxDC *dc);
   void OnErase(wxEraseEvent &event);
   void OnPaint(wxPaintEvent &event);
   void OnGOControl(wxCommandEvent &event);
+
+  /**
+   * Stores m_PressedPoint and calls m_Panel->HandleMousePress with relative
+   * coords
+   */
+  void HandleMousePress(const wxPoint &point, bool isRight);
+  /**
+   * calls m_Panel->HandleMouseRelease and clears m_PressedPoint
+   */
+  void HandleMouseRelease(bool isRight);
+
   void OnMouseMove(wxMouseEvent &event);
   void OnMouseLeftDown(wxMouseEvent &event);
+  void OnMouseLeftUp(wxMouseEvent &event);
+  void OnMouseLeftDclick(wxMouseEvent &event);
   void OnMouseRightDown(wxMouseEvent &event);
   void OnMouseScroll(wxMouseEvent &event);
   bool ForwardMouseEvent(wxMouseEvent &event);
