@@ -10,11 +10,11 @@
 
 #include "midi/GOMidiReceiverBase.h"
 
-class GODefinitionFile;
+class GOOrganController;
 
 class GOMidiReceiver : public GOMidiReceiverBase {
 private:
-  GODefinitionFile *m_organfile;
+  GOOrganController *m_OrganController;
   int m_Index;
 
 protected:
@@ -22,13 +22,13 @@ protected:
   int GetTranspose();
 
 public:
-  GOMidiReceiver(GODefinitionFile *organfile, GOMidiReceiverType type);
+  GOMidiReceiver(GOOrganController *organController, GOMidiReceiverType type);
 
-  void Load(GOConfigReader &cfg, wxString group, GOMidiMap &map);
+  void Load(GOConfigReader &cfg, const wxString &group, GOMidiMap &map);
 
   void SetIndex(int index);
 
-  void Assign(const GOMidiReceiverData &data);
+  void Assign(const GOMidiReceiverEventPatternList &data);
 };
 
 #endif
