@@ -13,15 +13,16 @@
 
 #include <vector>
 
-#include "GOElementCreator.h"
-#include "GOLabel.h"
+#include "control/GOElementCreator.h"
+#include "control/GOLabelControl.h"
+
 #include "GOTime.h"
 #include "GOTimerCallback.h"
 #include "ptrvector.h"
 
 class GOMidiEvent;
 class GOMidiMap;
-class GODefinitionFile;
+class GOOrganController;
 
 class GOMidiRecorder : public GOElementCreator, private GOTimerCallback {
   typedef struct {
@@ -31,9 +32,9 @@ class GOMidiRecorder : public GOElementCreator, private GOTimerCallback {
   } midi_map;
 
 private:
-  GODefinitionFile *m_organfile;
+  GOOrganController *m_OrganController;
   GOMidiMap &m_Map;
-  GOLabel m_RecordingTime;
+  GOLabelControl m_RecordingTime;
   unsigned m_RecordSeconds;
   unsigned m_NextChannel;
   unsigned m_NextNRPN;
@@ -48,10 +49,11 @@ private:
   unsigned m_FileLength;
   GOTime m_Last;
 
-  static const struct ElementListEntry m_element_types[];
-  const struct ElementListEntry *GetButtonList();
+  static const struct GOElementCreator::ButtonDefinitionEntry m_element_types[];
+  const struct GOElementCreator::ButtonDefinitionEntry *
+  GetButtonDefinitionList();
 
-  void ButtonChanged(int id);
+  void ButtonStateChanged(int id);
 
   void UpdateDisplay();
   void HandleTimer();
@@ -65,7 +67,7 @@ private:
   bool SetupMapping(unsigned element, bool isNRPN);
 
 public:
-  GOMidiRecorder(GODefinitionFile *organfile);
+  GOMidiRecorder(GOOrganController *organController);
   ~GOMidiRecorder();
 
   void SetOutputDevice(const wxString &device_id);
@@ -84,7 +86,7 @@ public:
 
   void Load(GOConfigReader &cfg);
   GOEnclosure *GetEnclosure(const wxString &name, bool is_panel);
-  GOLabel *GetLabel(const wxString &name, bool is_panel);
+  GOLabelControl *GetLabelControl(const wxString &name, bool is_panel);
 };
 
 #endif
