@@ -2,7 +2,7 @@
  * GrandOrgue - free pipe organ simulator based on MyOrgan
  *
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -143,11 +143,19 @@ float *resample_block(
     float out4 = 0.0f;
     const float *coef_set = &coef[position_fraction << SUBFILTER_BITS];
     float *in_set = &data[position_index];
+    unsigned max_i = len - position_index;
+
     for (unsigned j = 0; j < SUBFILTER_TAPS; j += 4) {
-      out1 += in_set[j] * coef_set[j];
-      out2 += in_set[j + 1] * coef_set[j + 1];
-      out3 += in_set[j + 2] * coef_set[j + 2];
-      out4 += in_set[j + 3] * coef_set[j + 3];
+      unsigned k = j;
+
+      if (k < max_i)
+        out1 += in_set[k] * coef_set[k];
+      if (++k < max_i)
+        out2 += in_set[k] * coef_set[k];
+      if (++k < max_i)
+        out3 += in_set[k] * coef_set[k];
+      if (++k < max_i)
+        out4 += in_set[k] * coef_set[k];
     }
     out[i] = out1 + out2 + out3 + out4;
   }
