@@ -7,11 +7,12 @@
 
 #include "GOSoundWindchestWorkItem.h"
 
-#include "GOSoundTremulantWorkItem.h"
-#include "GOWindchest.h"
+#include "model/GOWindchest.h"
 #include "sound/GOSoundEngine.h"
 #include "threading/GOMutexLocker.h"
 
+#include "GOSoundTremulantWorkItem.h"
+
 GOSoundWindchestWorkItem::GOSoundWindchestWorkItem(
   GOSoundEngine &sound_engine, GOWindchest *windchest)
   : m_engine(sound_engine),
